Subject: 25.0.95; Doc fixes (grammar, typos, clarification)
From: Stephen Berman <[email-masked]>
To: [email-masked]
Date: Sat, 11 Jun 2016 17:54:04 +0200
List-Id: <debbugs-submit.debbugs.gnu.org>

In GNU Emacs 25.0.95.1 (x86_64-suse-linux-gnu, GTK+ Version 3.14.15)
 of 2016-06-11 built on rosalinde
Repository revision: 6921f4a5961fb53f8fb24d1a5a3f94266f990f6e

diff --git a/doc/emacs/files.texi b/doc/emacs/files.texi
index 3bbb3cd..fc46ef7 100644
--- a/doc/emacs/files.texi
+++ b/doc/emacs/files.texi
@@ -701,7 +701,7 @@ Customize Save
 can undo it.)  If the value is @code{visit-save}, Emacs adds such
 newlines both on visiting and on saving.  If the value is @code{nil},
 Emacs leaves the end of the file unchanged; any other non-@code{nil}
-value means to asks you whether to add a newline.  The default is
+value means Emacs asks you whether to add a newline.  The default is
 @code{nil}.
 
 @vindex mode-require-final-newline
diff --git a/doc/emacs/frames.texi b/doc/emacs/frames.texi
index a7e709f..7e60062 100644
--- a/doc/emacs/frames.texi
+++ b/doc/emacs/frames.texi
@@ -1011,7 +1011,7 @@ Window Dividers
 
   On graphical displays, you can use @dfn{window dividers} in order to
 separate windows visually.  Window dividers are bars that can be dragged
-with the mouse, thus allowing to easily resize adjacent windows.
+with the mouse, thus allowing you to easily resize adjacent windows.
 
 @findex window-divider-mode
   To toggle the display of window dividers, use the command @kbd{M-x
diff --git a/doc/emacs/misc.texi b/doc/emacs/misc.texi
index 497a4ab..853b978 100644
--- a/doc/emacs/misc.texi
+++ b/doc/emacs/misc.texi
@@ -1885,7 +1885,7 @@ Printing
 @findex lpr-region
 @vindex lpr-switches
 @vindex lpr-commands
-  On most operating system, the above hardcopy commands submit files
+  On most operating systems, the above hardcopy commands submit files
 for printing by calling the @command{lpr} program.  To change the
 printer program, customize the variable @code{lpr-command}.  To
 specify extra switches to give the printer program, customize the list
diff --git a/doc/lispref/compile.texi b/doc/lispref/compile.texi
index c943a6a..f6cd022 100644
--- a/doc/lispref/compile.texi
+++ b/doc/lispref/compile.texi
@@ -438,7 +438,7 @@ Compiler Errors
 messages.
 
   When an error is due to invalid syntax in the program, the byte
-compiler might get confused about the errors' exact location.  One way
+compiler might get confused about the error's exact location.  One way
 to investigate is to switch to the buffer @w{@file{ *Compiler
 Input*}}.  (This buffer name starts with a space, so it does not show
 up in the Buffer Menu.)  This buffer contains the program being
diff --git a/doc/lispref/control.texi b/doc/lispref/control.texi
index 0cdb035..6179500 100644
--- a/doc/lispref/control.texi
+++ b/doc/lispref/control.texi
@@ -289,11 +289,11 @@ Conditionals
 @end example
 
 @menu
-* Pattern matching case statement::
+* Pattern Matching Case Statement::
 @end menu
 
-@node Pattern matching case statement
-@subsection Pattern matching case statement
+@node Pattern Matching Case Statement
+@subsection Pattern Matching Case Statement
 @cindex pcase
 @cindex pattern matching
 
diff --git a/doc/lispref/elisp.texi b/doc/lispref/elisp.texi
index a3bff0b..f9f155e 100644
--- a/doc/lispref/elisp.texi
+++ b/doc/lispref/elisp.texi
@@ -469,7 +469,7 @@ Top
 
 Conditionals
 
-* Pattern matching case statement::  How to use @code{pcase}.
+* Pattern Matching Case Statement::  How to use @code{pcase}.
 
 Nonlocal Exits
 
diff --git a/doc/lispref/keymaps.texi b/doc/lispref/keymaps.texi
index 61ac80c..f5d3811 100644
--- a/doc/lispref/keymaps.texi
+++ b/doc/lispref/keymaps.texi
@@ -1368,7 +1368,7 @@ Changing Key Bindings
   The function @code{substitute-key-definition} scans a keymap for
 keys that have a certain binding and rebinds them with a different
 binding.  Another feature which is cleaner and can often produce the
-same results to remap one command into another (@pxref{Remapping
+same results is to remap one command into another (@pxref{Remapping
 Commands}).
 
 @defun substitute-key-definition olddef newdef keymap &optional oldmap
diff --git a/doc/lispref/loading.texi b/doc/lispref/loading.texi
index d2d38d7..81a1922 100644
--- a/doc/lispref/loading.texi
+++ b/doc/lispref/loading.texi
@@ -848,8 +848,8 @@ Named Features
 associated with @var{feature} are or will be available for other Lisp
 programs.
 
-The direct effect of calling @code{provide} is if not already in
-@var{features} then to add @var{feature} to the front of that list and
+The direct effect of calling @code{provide} is to add @var{feature} to
+the front of @code{features} if it is not already in that list and
 call any @code{eval-after-load} code waiting for it (@pxref{Hooks for
 Loading}).  The argument @var{feature} must be a symbol.
 @code{provide} returns @var{feature}.
diff --git a/doc/lispref/markers.texi b/doc/lispref/markers.texi
index 1c90466..1b4d74f 100644
--- a/doc/lispref/markers.texi
+++ b/doc/lispref/markers.texi
@@ -340,10 +340,10 @@ Marker Insertion Types
 This function reports the current insertion type of @var{marker}.
 @end defun
 
-Most functions that create markers, without an argument allowing to
-specify the insertion type, create them with insertion type
-@code{nil}.  Also, the mark has, by default, insertion type
-@code{nil}.
+All functions that create markers without accepting an argument that
+specifies the insertion type, create them with insertion type
+@code{nil} (@pxref{Creating Markers}).  Also, the mark has, by
+default, insertion type @code{nil}.
 
 @node Moving Markers
 @section Moving Marker Positions
diff --git a/doc/lispref/modes.texi b/doc/lispref/modes.texi
index ae79128..4c96e63 100644
--- a/doc/lispref/modes.texi
+++ b/doc/lispref/modes.texi
@@ -899,7 +899,7 @@ Mode Hooks
 or fail to run @code{after-change-major-mode-hook}.  If you encounter
 such a major mode, please correct it to follow these conventions.
 
-  When you defined a major mode using @code{define-derived-mode}, it
+  When you define a major mode using @code{define-derived-mode}, it
 automatically makes sure these conventions are followed.  If you
 define a major mode ``by hand'', not using @code{define-derived-mode},
 use the following functions to handle these conventions automatically.
@@ -1048,7 +1048,7 @@ Tabulated List Mode
 @defun tabulated-list-init-header
 This function computes and sets @code{header-line-format} for the
 Tabulated List buffer (@pxref{Header Lines}), and assigns a keymap to
-the header line to allow sort entries by clicking on column headers.
+the header line to allow sorting entries by clicking on column headers.
 
 Modes derived from Tabulated List mode should call this after setting
 the above variables (in particular, only after setting
diff --git a/doc/lispref/processes.texi b/doc/lispref/processes.texi
index 03ae1f0..4977d2c 100644
--- a/doc/lispref/processes.texi
+++ b/doc/lispref/processes.texi
@@ -506,7 +506,7 @@ Synchronous Processes
 @defun call-process-shell-command command &optional infile destination display
 This function executes the shell command @var{command} synchronously.
 The arguments are handled as in @code{call-process}.  An old calling
-convention allowed to pass any number of additional arguments after
+convention allowed passing any number of additional arguments after
 @var{display}, which were concatenated to @var{command}; this is still
 supported, but strongly discouraged.
 @end defun
@@ -515,7 +515,7 @@ Synchronous Processes
 This function is like @code{call-process-shell-command}, but uses
 @code{process-file} internally.  Depending on @code{default-directory},
 @var{command} can be executed also on remote hosts.  An old calling
-convention allowed to pass any number of additional arguments after
+convention allowed passing any number of additional arguments after
 @var{display}, which were concatenated to @var{command}; this is still
 supported, but strongly discouraged.
 @end defun
@@ -1382,12 +1382,13 @@ Process Buffers
 @end defun
 
 If the process's buffer is displayed in a window, your Lisp program
-may wish telling the process the dimensions of that window, so that
-the process could adapt its output to those dimensions, much as it
-adapts to the screen dimensions.  The following functions allow to
-communicate this kind of information to processes; however, not all
-systems support the underlying functionality, so it is best to provide
-fallbacks, e.g., via command-line arguments or environment variables.
+may wish to tell the process the dimensions of that window, so that
+the process can adapt its output to those dimensions, much as it
+adapts to the screen dimensions.  The following functions allow your
+program to communicate this kind of information to processes; however,
+not all systems support the underlying functionality, so it is best to
+provide fallbacks, e.g., via command-line arguments or environment
+variables.
 
 @defun set-process-window-size process height width
 Tell @var{process} that its logical window size has dimensions
diff --git a/doc/lispref/text.texi b/doc/lispref/text.texi
index 96f109b..7791c26 100644
--- a/doc/lispref/text.texi
+++ b/doc/lispref/text.texi
@@ -1376,10 +1376,10 @@ Undo
 the effects of one command.  A few exceptional commands are
 @dfn{amalgamating}: these commands generally cause small changes to
 buffers, so with these a boundary is inserted only every 20th command,
-allowing to undo them as a group.  By default, commands
+allowing the changes to be undone as a group.  By default, the commands
 @code{self-insert-command}, which produces self-inserting input
-characters (@pxref{Commands for Insertion}), and @code{delete-char}
-which deletes characters (@pxref{Deletion}) are amalgamating.
+characters (@pxref{Commands for Insertion}), and @code{delete-char},
+which deletes characters (@pxref{Deletion}), are amalgamating.
 Where a command affects the contents of several buffers, as may happen,
 for example, when a function on the @code{post-command-hook} affects a
 buffer other than the @code{current-buffer}, then @code{undo-boundary}
diff --git a/src/xfaces.c b/src/xfaces.c
index 88f5f34..5077cb2 100644
--- a/src/xfaces.c
+++ b/src/xfaces.c
@@ -6503,8 +6503,8 @@ REPLACEMENT is a face specification, i.e. one of the following:
   (3) a list in which each element has the form of (1) or (2).
 
 List values for REPLACEMENT are merged to form the final face
-specification, with earlier entries taking precedence, in the same as
-as in the `face' text property.
+specification, with earlier entries taking precedence, in the same way
+as with the `face' text property.
 
 Face-name remapping cycles are suppressed; recursive references use
 the underlying face instead of the remapped face.  So a remapping of
diff --git a/src/floatfns.c b/src/floatfns.c
index c1bd258..f514fcb 100644
--- a/src/floatfns.c
+++ b/src/floatfns.c
@@ -185,8 +185,8 @@ If X is zero, both parts (SGNFCAND and EXP) are zero.  */)
 }
 
 DEFUN ("ldexp", Fldexp, Sldexp, 2, 2, 0,
-       doc: /* Return X * 2**EXP, as a floating point number.
-EXP must be an integer.   */)
+       doc: /* Return SGNFCAND * 2**EXPONENT, as a floating point number.
+EXPONENT must be an integer.   */)
   (Lisp_Object sgnfcand, Lisp_Object exponent)
 {
   CHECK_NUMBER (exponent);